@@ -83,6 +83,8 @@ class TestSerialAndParsing(unittest.TestCase):
         self.dots = u'1\n00:01:00.000 --> 00:01:20.000\nHello world !\n'
         self.string_index = u'foo\n00:01:00,000 --> 00:01:20,000\nHello !\n'
         self.no_index = u'00:01:00,000 --> 00:01:20,000\nHello world !\n'
+        self.junk_after_timestamp = (u'1\n00:01:00,000 --> 00:01:20,000?\n'
+                                'Hello world !\n')
 
     def test_serialization(self):
         self.assertEqual(unicode(self.item), self.string)
@@ -127,3 +129,7 @@ class TestSerialAndParsing(unittest.TestCase):
         item = SubRipItem.from_string(self.no_index)
         self.assertEquals(item.index, None)
         self.assertEquals(item.text, 'Hello world !')
+
+    def test_junk_after_timestamp(self):
+        item = SubRipItem.from_string(self.junk_after_timestamp)
+        self.assertEquals(item, self.item)
